#!/bin/bash
# vim: tabstop=4:softtabstop=4:shiftwidth=4:noexpandtab

basedir=~/.socr/work
logsdir=~/.socr/logs

PATH="${PATH}:/usr/sbin:/usr/local/bin:/opt/local/bin"

frame="${KMPARAM_X},${KMPARAM_Y},${KMPARAM_Width},${KMPARAM_Height}"
name="socr_$(date '+%Y-%m-%d_%H.%M.%S')_at_${frame}"
logfile="${logsdir}/socr_log_$(date '+%Y-%m-%d').txt"

mkdir -p "${basedir}"
mkdir -p "${logsdir}"
basename="${basedir}/${name}"


if [ ! -z "$(which screencapture)" ]; then
  SCREENCAPTURE="$(which screencapture)"
else
  printf "FATAL ERROR: Could not find screencapture.\n" 2>&1
fi

if [ ! -z "$(which mogrify)" ]; then
  MOGRIFY="$(which mogrify)"
else
  printf "FATAL ERROR: Could not find mogrify.\nMake sure MacPorts (http://macports.org) is installed, then do 'sudo port install ImageMagick'.\n" 2>&1
fi

if [ ! -z "$(which tesseract)" ]; then
  TESSERACT="$(which tesseract)"
else
  printf "FATAL ERROR: Could not find tesseract.\nMake sure MacPorts (http://macports.org) is installed, then do 'sudo port install tesseract'.\nYou will also need to install the language file you would like tesseract to understand, eg. 'port install tesseract-eng'.\n" 2>&1
fi


echo >> "${logfile}"
echo "============================================================================" >> "${logfile}"
echo "interactively: ${KMPARAM_Prompt_User_Interactively}" >> "${logfile}"
echo "frame: ${frame}" >> "${logfile}"
echo "name: ${name}" >> "${logfile}"

if [ "${KMPARAM_Prompt_User_Interactively}" -eq 1 ]; then
	${SCREENCAPTURE} -i "${basename}.png" >> "${logfile}" 2>&1
else
	${SCREENCAPTURE} -R${frame} -T0 "${basename}.png" >> "${logfile}" 2>&1
fi

if [ ! -e "${basename}.png" ]; then
	printf "screencapture failed"
	exit 1
fi

# There are seemingly endless ways to tweak the image in pre-processing.  We
# do very minimal tweak here.
#
# Sometimes it's better strip all color (-modulate 100,0)
#   http://www.imagemagick.org/script/command-line-options.php#modulate
#${MOGRIFY} -modulate 100,0 -resize 500% "${basename}.png" >> "${logfile}" 2>&1
#
# Increasing size by 500% helps with screenshots where fonts are typically very small
# compared to what you'd expect from a scanned image.
${MOGRIFY} -resize 500% "${basename}.png" >> "${logfile}" 2>&1

# Process PNG and get basename.TXT file
${TESSERACT} "${basename}.png" "${basename}" 2>> "${logfile}"


if [ "${KMPARAM_Remove_Newlines}" == "None" ]; then
	tee -a "${logfile}" < "${basename}.txt"
elif [ "${KMPARAM_Remove_Newlines}" == "All" ]; then
	tr -d '\n' < "${basename}.txt" | tee -a "${logfile}"
elif [ "${KMPARAM_Remove_Newlines}" == "Join" ]; then
	echo $(cat "${basename}.txt") | tee -a "${logfile}"
elif [ "${KMPARAM_Remove_Newlines}" == "Trailing" ]; then
	echo "$(cat "${basename}.txt")" | tee -a "${logfile}"
else
	printf 'Unknown "Remove Newlines" value: "%s"' "${KMPARAM_Remove_Newlines}" 1>&2
	exit 1
fi

find ~/.socr -type f -exec rm {} \; &> /dev/null

exit 0


# EOF
